/*
  Analog read for PH probe 10 bit.
 
 Reads an analog input pin, ANALOG PIN 0 and sends the data to the serial port.
 
 Protocol:
 The protocol is a three byte data package,
 Header = 0;
 PhHi   = Hi-byte of 10 bit & address (64 addresses max)
 PhLo   = Lo-byte.
 
  The circuit:
 * Connect the PH probe to the AN0 (analog 0) 
 
   created 22 May. 2013
   Martin Hug
 
 */
 
 
// variables declaration:

const int analogInPin = A0; // Analog input pin that the Ph probe is connected.

int sensorValue = 0;        // 10bit value read from the PH probe.
byte address = 4;           // 00000100, first possible address.
byte PhLo = 0;              // Lo-byte of 10 bit data.
byte PhHi = 0;              // Hi-byte of 10 bit data.

void setup() {
  // set PORTB, GPIO_9 del WiFly (PB0), LED (PB1) & 3V(PB2).
  DDRB = B00000111; 
  
  Serial.begin(9600); 
}

void loop() {
  PORTB = B00000111;   // WiFly connect to local red, LED ON , 3V ON.
  sensorValue = analogRead(analogInPin);            

  PhHi = address | sensorValue>>8; // merge adddress and upper byte.
  PhLo = sensorValue;              // lower byte. 
  

  // print the results to the serial monitor:
  // Use Serial.println ASCII for(Pd) and  Serial.write DECINAL for SuperCollider (and Serial Monitor). 
  
  // for Pd-extended   
  /*Serial.println(0);    // header byte.
  Serial.println(PhHi); // first byte. 
  Serial.println(PhLo); // second byte.*/
  
  // for SuperCollider
  Serial.write(0);    // header byte.
  Serial.write(PhHi); // first byte. 
  Serial.write(PhLo); // second byte.
  
  
  delay(50);  // increase value for slower data transfer.                   
}

